## Version 1.3.0 (2025-12-10)

### Issues Closed

* [Issue 360](https://github.com/spyder-ide/spyder-terminal/issues/360) - Release spyder-terminal 1.3.0
* [Issue 348](https://github.com/spyder-ide/spyder-terminal/issues/348) - Spyder Terminal Cannot Restart/White Screen ([PR 358](https://github.com/spyder-ide/spyder-terminal/pull/358) by [@dalthviz](https://github.com/dalthviz))
* [Issue 345](https://github.com/spyder-ide/spyder-terminal/issues/345) - Error with Spyder 6 ([PR 355](https://github.com/spyder-ide/spyder-terminal/pull/355) by [@dalthviz](https://github.com/dalthviz))
* [Issue 344](https://github.com/spyder-ide/spyder-terminal/issues/344) - Focus lost when switching between terminal and other panes ([PR 362](https://github.com/spyder-ide/spyder-terminal/pull/362) by [@dalthviz](https://github.com/dalthviz))
* [Issue 342](https://github.com/spyder-ide/spyder-terminal/issues/342) - Several errors on FreeBSD ([PR 356](https://github.com/spyder-ide/spyder-terminal/pull/356) by [@dalthviz](https://github.com/dalthviz))
* [Issue 335](https://github.com/spyder-ide/spyder-terminal/issues/335) - Multiple tabs not working ([PR 358](https://github.com/spyder-ide/spyder-terminal/pull/358) by [@dalthviz](https://github.com/dalthviz))
* [Issue 327](https://github.com/spyder-ide/spyder-terminal/issues/327) - Uncaught ReferenceError: spyder_terminal is not defined ([PR 361](https://github.com/spyder-ide/spyder-terminal/pull/361) by [@dalthviz](https://github.com/dalthviz))

In this release 7 issues were closed.

### Pull Requests Merged

* [PR 362](https://github.com/spyder-ide/spyder-terminal/pull/362) - PR: Set `RAISE_AND_FOCUS` to `True` to give focus to terminal prompt, by [@dalthviz](https://github.com/dalthviz) ([344](https://github.com/spyder-ide/spyder-terminal/issues/344))
* [PR 361](https://github.com/spyder-ide/spyder-terminal/pull/361) - PR: Prevent `ReferenceError` due to JS eval calls before page load, by [@dalthviz](https://github.com/dalthviz) ([327](https://github.com/spyder-ide/spyder-terminal/issues/327))
* [PR 359](https://github.com/spyder-ide/spyder-terminal/pull/359) - PR: Bump express from 4.21.2 to 4.22.1, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 358](https://github.com/spyder-ide/spyder-terminal/pull/358) - PR: Add remote terminals menu using remote client connections info, update Spyder and Python min version requirements and other fixes, by [@dalthviz](https://github.com/dalthviz) ([348](https://github.com/spyder-ide/spyder-terminal/issues/348), [335](https://github.com/spyder-ide/spyder-terminal/issues/335))
* [PR 357](https://github.com/spyder-ide/spyder-terminal/pull/357) - PR: Bump node-forge from 1.3.1 to 1.3.2, by [@dependabot[bot]](https://github.com/apps/dependabot) ([](https://github.com/typos.</issues/), [](https://github.com/typo.</issues/), [](https://github.com/style.</issues/))
* [PR 356](https://github.com/spyder-ide/spyder-terminal/pull/356) - PR: Use `sh` as a default shell on BSD systems, by [@spchamp](https://github.com/spchamp) [@dalthviz](https://github.com/dalthviz) ([342](https://github.com/spyder-ide/spyder-terminal/issues/342))
* [PR 355](https://github.com/spyder-ide/spyder-terminal/pull/355) - PR: Fix compatibility for Spyder 6 and update to xterm.js 5.5.0, by [@Zybulon](https://github.com/Zybulon) [@dalthviz](https://github.com/dalthviz) ([345](https://github.com/spyder-ide/spyder-terminal/issues/345))
* [PR 353](https://github.com/spyder-ide/spyder-terminal/pull/353) - PR: Add Ubuntu Font License to LICENSE.txt, by [@juliangilbey](https://github.com/juliangilbey)
* [PR 352](https://github.com/spyder-ide/spyder-terminal/pull/352) - PR: Replace deprecated `distutils` and `pipes` modules, by [@juliangilbey](https://github.com/juliangilbey)

In this release 9 pull requests were closed.


## Version 1.2.2 (2022-03-29)


### Pull Requests Merged

* [PR 316](https://github.com/spyder-ide/spyder-terminal/pull/316) - PR: Move CIs to github actions, by [@steff456](https://github.com/steff456)
* [PR 315](https://github.com/spyder-ide/spyder-terminal/pull/315) - PR: Prevent showing message for server errors when closing the plugin, by [@dalthviz](https://github.com/dalthviz)
* [PR 313](https://github.com/spyder-ide/spyder-terminal/pull/313) - PR: Update pywinpty version to v2.0.5, by [@andfoy](https://github.com/andfoy)

In this release 3 pull requests were closed.

## Version 1.2.1 (2022-02-02)

### Issues Closed

* [Issue 302](https://github.com/spyder-ide/spyder-terminal/issues/302) - Zoom level increases by 2x every time a Terminal is opened. ([PR 308](https://github.com/spyder-ide/spyder-terminal/pull/308) by [@steff456](https://github.com/steff456))

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 308](https://github.com/spyder-ide/spyder-terminal/pull/308) - PR: Fix double zoom when openning a new terminal, by [@steff456](https://github.com/steff456) ([302](https://github.com/spyder-ide/spyder-terminal/issues/302))
* [PR 306](https://github.com/spyder-ide/spyder-terminal/pull/306) - Test pywinpty 2.0.1 on CI, by [@andfoy](https://github.com/andfoy)
* [PR 305](https://github.com/spyder-ide/spyder-terminal/pull/305) - PR: Update CIs, by [@steff456](https://github.com/steff456)
* [PR 298](https://github.com/spyder-ide/spyder-terminal/pull/298) - PR: Increase minimal Spyder version in setup.py, by [@ccordoba12](https://github.com/ccordoba12)

In this release 4 pull requests were closed.


## Version 1.2.0 (2021-12-16)

### Issues Closed

* [Issue 285](https://github.com/spyder-ide/spyder-terminal/issues/285) - Default workdir ([PR 295](https://github.com/spyder-ide/spyder-terminal/pull/295) by [@steff456](https://github.com/steff456))

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 295](https://github.com/spyder-ide/spyder-terminal/pull/295) - PR: Open new terminals in the project path if active, by [@steff456](https://github.com/steff456) ([285](https://github.com/spyder-ide/spyder-terminal/issues/285))
* [PR 294](https://github.com/spyder-ide/spyder-terminal/pull/294) - PR: Update to xterm 4.15, by [@steff456](https://github.com/steff456)
* [PR 293](https://github.com/spyder-ide/spyder-terminal/pull/293) - PR: Update to Spyder 5.2.x API, by [@steff456](https://github.com/steff456)
* [PR 289](https://github.com/spyder-ide/spyder-terminal/pull/289) - PR: Update installation instructions for conda, by [@ccordoba12](https://github.com/ccordoba12)

In this release 4 pull requests were closed.

## Version 1.1.0 (2021/08/12)


### Pull Requests Merged

* [PR 281](https://github.com/spyder-ide/spyder-terminal/pull/281) - PR: Migrate registry to the new Spyder 5.1 API, by [@steff456](https://github.com/steff456)

In this release 1 pull request was closed.

## Version 1.0.0 (2021-07-07)

### Issues Closed

* [Issue 264](https://github.com/spyder-ide/spyder-terminal/issues/264) - Use QProcess instead of subprocess.Popen ([PR 273](https://github.com/spyder-ide/spyder-terminal/pull/273) by [@steff456](https://github.com/steff456))
* [Issue 253](https://github.com/spyder-ide/spyder-terminal/issues/253) - Spyder-terminal never shows up on menu or as tabbed windows ([PR 255](https://github.com/spyder-ide/spyder-terminal/pull/255) by [@steff456](https://github.com/steff456))
* [Issue 252](https://github.com/spyder-ide/spyder-terminal/issues/252) - Spyder 5 support ([PR 255](https://github.com/spyder-ide/spyder-terminal/pull/255) by [@steff456](https://github.com/steff456))
* [Issue 250](https://github.com/spyder-ide/spyder-terminal/issues/250) - Shell interpreter: Anaconda Power Shell Prompt ([PR 271](https://github.com/spyder-ide/spyder-terminal/pull/271) by [@steff456](https://github.com/steff456))
* [Issue 247](https://github.com/spyder-ide/spyder-terminal/issues/247) - Setting default font size ([PR 268](https://github.com/spyder-ide/spyder-terminal/pull/268) by [@steff456](https://github.com/steff456))
* [Issue 164](https://github.com/spyder-ide/spyder-terminal/issues/164) - Spyder terminal does not activate conda environments and keeps asking to "conda init" even after initialization. ([PR 271](https://github.com/spyder-ide/spyder-terminal/pull/271) by [@steff456](https://github.com/steff456))

In this release 6 issues were closed.

### Pull Requests Merged

* [PR 276](https://github.com/spyder-ide/spyder-terminal/pull/276) - PR: Update translations for Spyder 1.0.0 release, by [@steff456](https://github.com/steff456)
* [PR 275](https://github.com/spyder-ide/spyder-terminal/pull/275) - PR: Pin new version of Spyder and Pywinpty, by [@steff456](https://github.com/steff456)
* [PR 273](https://github.com/spyder-ide/spyder-terminal/pull/273) - PR: Change subprocess.Popen to QProcess, by [@steff456](https://github.com/steff456) ([264](https://github.com/spyder-ide/spyder-terminal/issues/264))
* [PR 272](https://github.com/spyder-ide/spyder-terminal/pull/272) - PR: Add blue border when the terminal is focused, by [@steff456](https://github.com/steff456)
* [PR 271](https://github.com/spyder-ide/spyder-terminal/pull/271) - PR: Source terminal config files to have conda in PATH, by [@steff456](https://github.com/steff456) ([250](https://github.com/spyder-ide/spyder-terminal/issues/250), [164](https://github.com/spyder-ide/spyder-terminal/issues/164))
* [PR 270](https://github.com/spyder-ide/spyder-terminal/pull/270) - PR: Add note to Readme to mention that this plugin doesn't work with our installers, by [@ccordoba12](https://github.com/ccordoba12)
* [PR 268](https://github.com/spyder-ide/spyder-terminal/pull/268) - PR: Add new cursor option and zoom to the terminal, by [@steff456](https://github.com/steff456) ([247](https://github.com/spyder-ide/spyder-terminal/issues/247))
* [PR 267](https://github.com/spyder-ide/spyder-terminal/pull/267) - PR: Upgrade to xtermjs 4.13.0, by [@steff456](https://github.com/steff456)
* [PR 255](https://github.com/spyder-ide/spyder-terminal/pull/255) - PR: Migration to Spyder 5 new API, by [@steff456](https://github.com/steff456) ([253](https://github.com/spyder-ide/spyder-terminal/issues/253), [252](https://github.com/spyder-ide/spyder-terminal/issues/252))

In this release 9 pull requests were closed.

## Version 0.5.0 (2020-11-16)

### Issues Closed

* [Issue 242](https://github.com/spyder-ide/spyder-terminal/issues/242) - Terminal just displays a fat cursor and does nothing else ([PR 243](https://github.com/spyder-ide/spyder-terminal/pull/243) by [@steff456](https://github.com/steff456))
* [Issue 240](https://github.com/spyder-ide/spyder-terminal/issues/240) - Terminal tab not working on spyder 4.1.5, Ubuntu 20.04 ([PR 243](https://github.com/spyder-ide/spyder-terminal/pull/243) by [@steff456](https://github.com/steff456))

In this release 2 issues were closed.

### Pull Requests Merged

* [PR 244](https://github.com/spyder-ide/spyder-terminal/pull/244) - PR: Upgrade dependencies of xtermjs and Spyder, by [@steff456](https://github.com/steff456)
* [PR 243](https://github.com/spyder-ide/spyder-terminal/pull/243) - PR: Fix new terminal with work with latest Terminado version, by [@steff456](https://github.com/steff456) ([242](https://github.com/spyder-ide/spyder-terminal/issues/242), [240](https://github.com/spyder-ide/spyder-terminal/issues/240))

In this release 2 pull requests were closed.


## Version 0.4.2 (2020-08-17)


### Pull Requests Merged

* [PR 237](https://github.com/spyder-ide/spyder-terminal/pull/237) - PR: Add Xonsh to list of supported terminals in Unix and Windows, by [@steff456](https://github.com/steff456)

In this release 1 pull request was closed.


## Version 0.4.1 (2020/08/05)

### Issues Closed

* [Issue 235](https://github.com/spyder-ide/spyder-terminal/issues/235) - Plugin fails on Python 3.8 and Windows ([PR 236](https://github.com/spyder-ide/spyder-terminal/pull/236) by [@steff456](https://github.com/steff456))

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 236](https://github.com/spyder-ide/spyder-terminal/pull/236) - PR: Add tornado patch for python 3.8 in windows, by [@steff456](https://github.com/steff456) ([235](https://github.com/spyder-ide/spyder-terminal/issues/235))

In this release 1 pull request was closed.


## Version spyder-terminal v0.4.0 (2020/07/21)

### Issues Closed

* [Issue 233](https://github.com/spyder-ide/spyder-terminal/issues/233) - Update translations
* [Issue 227](https://github.com/spyder-ide/spyder-terminal/issues/227) - Add option to set buffer limit ([PR 228](https://github.com/spyder-ide/spyder-terminal/pull/228) by [@steff456](https://github.com/steff456))
* [Issue 225](https://github.com/spyder-ide/spyder-terminal/issues/225) - Terminal error "ValueError: Invalid cookie 'cwd'" ([PR 229](https://github.com/spyder-ide/spyder-terminal/pull/229) by [@steff456](https://github.com/steff456))
* [Issue 224](https://github.com/spyder-ide/spyder-terminal/issues/224) - Add widget for find functionality in the terminal ([PR 226](https://github.com/spyder-ide/spyder-terminal/pull/226) by [@steff456](https://github.com/steff456))
* [Issue 219](https://github.com/spyder-ide/spyder-terminal/issues/219) - Remove QWebKit from the code ([PR 221](https://github.com/spyder-ide/spyder-terminal/pull/221) by [@steff456](https://github.com/steff456))
* [Issue 218](https://github.com/spyder-ide/spyder-terminal/issues/218) - Shortcuts are not appearing in the preferences pane ([PR 222](https://github.com/spyder-ide/spyder-terminal/pull/222) by [@steff456](https://github.com/steff456))
* [Issue 213](https://github.com/spyder-ide/spyder-terminal/issues/213) - Update to xterm.js latest version ([PR 214](https://github.com/spyder-ide/spyder-terminal/pull/214) by [@steff456](https://github.com/steff456))
* [Issue 212](https://github.com/spyder-ide/spyder-terminal/issues/212) - Migrate this plugin to Python 3 ([PR 215](https://github.com/spyder-ide/spyder-terminal/pull/215) by [@steff456](https://github.com/steff456))
* [Issue 206](https://github.com/spyder-ide/spyder-terminal/issues/206) - Correctly generate logging files ([PR 210](https://github.com/spyder-ide/spyder-terminal/pull/210) by [@steff456](https://github.com/steff456))
* [Issue 202](https://github.com/spyder-ide/spyder-terminal/issues/202) - Problems when highlight text on terminal ([PR 216](https://github.com/spyder-ide/spyder-terminal/pull/216) by [@steff456](https://github.com/steff456))
* [Issue 148](https://github.com/spyder-ide/spyder-terminal/issues/148) - How to increase/decrease size of font in terminal? ([PR 217](https://github.com/spyder-ide/spyder-terminal/pull/217) by [@steff456](https://github.com/steff456))

In this release 11 issues were closed.

### Pull Requests Merged

* [PR 232](https://github.com/spyder-ide/spyder-terminal/pull/232) - New Crowdin updates, by [@spyder-bot](https://github.com/spyder-bot)
* [PR 231](https://github.com/spyder-ide/spyder-terminal/pull/231) - PR: Update translation files, by [@steff456](https://github.com/steff456)
* [PR 229](https://github.com/spyder-ide/spyder-terminal/pull/229) - PR: Percent encode/decode cwd to encode spaces and special characters, by [@steff456](https://github.com/steff456) ([225](https://github.com/spyder-ide/spyder-terminal/issues/225))
* [PR 228](https://github.com/spyder-ide/spyder-terminal/pull/228) - PR: Add scrollback option to the terminal, by [@steff456](https://github.com/steff456) ([227](https://github.com/spyder-ide/spyder-terminal/issues/227))
* [PR 226](https://github.com/spyder-ide/spyder-terminal/pull/226) - PR: Add find widget to the terminal, by [@steff456](https://github.com/steff456) ([224](https://github.com/spyder-ide/spyder-terminal/issues/224))
* [PR 223](https://github.com/spyder-ide/spyder-terminal/pull/223) - PR: Improve clipboard support in the terminal, by [@steff456](https://github.com/steff456)
* [PR 222](https://github.com/spyder-ide/spyder-terminal/pull/222) - PR: Fix shortcuts to new API, by [@steff456](https://github.com/steff456) ([218](https://github.com/spyder-ide/spyder-terminal/issues/218))
* [PR 221](https://github.com/spyder-ide/spyder-terminal/pull/221) - PR: Remove deprecated QWebKit code, by [@steff456](https://github.com/steff456) ([219](https://github.com/spyder-ide/spyder-terminal/issues/219))
* [PR 217](https://github.com/spyder-ide/spyder-terminal/pull/217) - PR: Add option to zoom in/zoom out in the terminal, by [@steff456](https://github.com/steff456) ([148](https://github.com/spyder-ide/spyder-terminal/issues/148))
* [PR 216](https://github.com/spyder-ide/spyder-terminal/pull/216) - PR: Fix highlight text on the terminal, by [@steff456](https://github.com/steff456) ([202](https://github.com/spyder-ide/spyder-terminal/issues/202))
* [PR 215](https://github.com/spyder-ide/spyder-terminal/pull/215) - PR: Move Spyder-terminal plugin to Python 3, by [@steff456](https://github.com/steff456) ([212](https://github.com/spyder-ide/spyder-terminal/issues/212))
* [PR 214](https://github.com/spyder-ide/spyder-terminal/pull/214) - PR: Upgrade xterm to 4.7 release, by [@steff456](https://github.com/steff456) ([213](https://github.com/spyder-ide/spyder-terminal/issues/213))
* [PR 211](https://github.com/spyder-ide/spyder-terminal/pull/211) - PR: Fix issues when running our test suite in Azure, by [@ccordoba12](https://github.com/ccordoba12)
* [PR 210](https://github.com/spyder-ide/spyder-terminal/pull/210) - PR: Generate logging files with Spyder's debug level, by [@steff456](https://github.com/steff456) ([206](https://github.com/spyder-ide/spyder-terminal/issues/206))
* [PR 208](https://github.com/spyder-ide/spyder-terminal/pull/208) - Bump websocket-extensions from 0.1.3 to 0.1.4, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 204](https://github.com/spyder-ide/spyder-terminal/pull/204) - Bump jquery from 3.4.1 to 3.5.0, by [@dependabot[bot]](https://github.com/apps/dependabot)

In this release 16 pull requests were closed.


## Version spyder-terminal v0.3.2 (2020/04/27)


### Pull Requests Merged

* [PR 201](https://github.com/spyder-ide/spyder-terminal/pull/201) - PR: Import sys for confpage, by [@bnavigator](https://github.com/bnavigator)

In this release 1 pull request was closed.

## Version spyder-terminal v0.3.1 (2020/04/21)

### Issues Closed

* [Issue 184](https://github.com/spyder-ide/spyder-terminal/issues/184) - Don't distribute our tests with the package ([PR 190](https://github.com/spyder-ide/spyder-terminal/pull/190) by [@steff456](https://github.com/steff456))
* [Issue 183](https://github.com/spyder-ide/spyder-terminal/issues/183) - Add testing requirements to setup.py ([PR 185](https://github.com/spyder-ide/spyder-terminal/pull/185) by [@steff456](https://github.com/steff456))
* [Issue 181](https://github.com/spyder-ide/spyder-terminal/issues/181) - Unknown mark pytest.mark.first on a test ([PR 186](https://github.com/spyder-ide/spyder-terminal/pull/186) by [@steff456](https://github.com/steff456))
* [Issue 180](https://github.com/spyder-ide/spyder-terminal/issues/180) - Declare DEV mode in tests using conftest.py ([PR 192](https://github.com/spyder-ide/spyder-terminal/pull/192) by [@steff456](https://github.com/steff456))
* [Issue 179](https://github.com/spyder-ide/spyder-terminal/issues/179) - test_terminal_resize assumes python command ([PR 191](https://github.com/spyder-ide/spyder-terminal/pull/191) by [@bnavigator](https://github.com/bnavigator))
* [Issue 177](https://github.com/spyder-ide/spyder-terminal/issues/177) - Command prompt shows wrong shell ([PR 193](https://github.com/spyder-ide/spyder-terminal/pull/193) by [@steff456](https://github.com/steff456))
* [Issue 176](https://github.com/spyder-ide/spyder-terminal/issues/176) - Update requirement to Spyder >=4.1.0 when released ([PR 178](https://github.com/spyder-ide/spyder-terminal/pull/178) by [@steff456](https://github.com/steff456))

In this release 7 issues were closed.

### Pull Requests Merged

* [PR 198](https://github.com/spyder-ide/spyder-terminal/pull/198) - PR: Add compatibility with the latest release of xterm, by [@steff456](https://github.com/steff456)
* [PR 197](https://github.com/spyder-ide/spyder-terminal/pull/197) - PR: Add some missing files to the distribution package, by [@ccordoba12](https://github.com/ccordoba12)
* [PR 196](https://github.com/spyder-ide/spyder-terminal/pull/196) - PR: Update release instructions with new loghub command, by [@ccordoba12](https://github.com/ccordoba12)
* [PR 195](https://github.com/spyder-ide/spyder-terminal/pull/195) - PR: Fix font size bug when resizing the terminal, by [@steff456](https://github.com/steff456)
* [PR 194](https://github.com/spyder-ide/spyder-terminal/pull/194) - PR: Do not set DEV but assert it has been set, by [@bnavigator](https://github.com/bnavigator)
* [PR 193](https://github.com/spyder-ide/spyder-terminal/pull/193) - PR: Change default terminal for macOS Catalina, by [@steff456](https://github.com/steff456) ([177](https://github.com/spyder-ide/spyder-terminal/issues/177))
* [PR 192](https://github.com/spyder-ide/spyder-terminal/pull/192) - PR: Add conftest.py and remove the SPYDER_DEV variable in the CIs, by [@steff456](https://github.com/steff456) ([180](https://github.com/spyder-ide/spyder-terminal/issues/180))
* [PR 191](https://github.com/spyder-ide/spyder-terminal/pull/191) - PR: Use sys.executable in test_terminal_resize, by [@bnavigator](https://github.com/bnavigator) ([179](https://github.com/spyder-ide/spyder-terminal/issues/179), [179](https://github.com/spyder-ide/spyder-terminal/issues/179))
* [PR 190](https://github.com/spyder-ide/spyder-terminal/pull/190) - PR: Exclude tests from distribution package, by [@steff456](https://github.com/steff456) ([184](https://github.com/spyder-ide/spyder-terminal/issues/184))
* [PR 189](https://github.com/spyder-ide/spyder-terminal/pull/189) - PR: Bump acorn from 6.4.0 to 6.4.1, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 188](https://github.com/spyder-ide/spyder-terminal/pull/188) - PR: Resolve vulnerabilities, by [@steff456](https://github.com/steff456)
* [PR 187](https://github.com/spyder-ide/spyder-terminal/pull/187) - PR: Update deprecated dependencies and remove Python 2 from CIs, by [@steff456](https://github.com/steff456)
* [PR 186](https://github.com/spyder-ide/spyder-terminal/pull/186) - PR: Remove unnecessary pytest first marker, by [@steff456](https://github.com/steff456) ([181](https://github.com/spyder-ide/spyder-terminal/issues/181))
* [PR 185](https://github.com/spyder-ide/spyder-terminal/pull/185) - PR: Add testing requirements to setup.py, by [@steff456](https://github.com/steff456) ([183](https://github.com/spyder-ide/spyder-terminal/issues/183))
* [PR 178](https://github.com/spyder-ide/spyder-terminal/pull/178) - PR: Update Spyder requirement to 4.1, by [@steff456](https://github.com/steff456) ([176](https://github.com/spyder-ide/spyder-terminal/issues/176))

In this release 15 pull requests were closed.


## Version 0.3.0 (2020-02-05)

### Issues Closed

* [Issue 168](https://github.com/spyder-ide/spyder-terminal/issues/168) - Change "terminal" to "consola" in Spanish translation ([PR 169](https://github.com/spyder-ide/spyder-terminal/pull/169))
* [Issue 161](https://github.com/spyder-ide/spyder-terminal/issues/161) - Some UI/UX improvements for 0.3.0 ([PR 166](https://github.com/spyder-ide/spyder-terminal/pull/166))
* [Issue 159](https://github.com/spyder-ide/spyder-terminal/issues/159) - Test new localization scripts ([PR 156](https://github.com/spyder-ide/spyder-terminal/pull/156))
* [Issue 158](https://github.com/spyder-ide/spyder-terminal/issues/158) - Add correct localization handling
* [Issue 149](https://github.com/spyder-ide/spyder-terminal/issues/149) - Spyder-terminal is not starting on spyder 4 beta 2 ([PR 150](https://github.com/spyder-ide/spyder-terminal/pull/150))
* [Issue 138](https://github.com/spyder-ide/spyder-terminal/issues/138) - Implement JS routines using ES6/JSX syntax ([PR 153](https://github.com/spyder-ide/spyder-terminal/pull/153))
* [Issue 137](https://github.com/spyder-ide/spyder-terminal/issues/137) - Migrate JS dependencies to Yarn ([PR 141](https://github.com/spyder-ide/spyder-terminal/pull/141))
* [Issue 126](https://github.com/spyder-ide/spyder-terminal/issues/126) - xterm 3.0 (switched from DOM to canvas) ([PR 153](https://github.com/spyder-ide/spyder-terminal/pull/153))
* [Issue 122](https://github.com/spyder-ide/spyder-terminal/issues/122) - Use Terminado as backend terminal server handler ([PR 142](https://github.com/spyder-ide/spyder-terminal/pull/142))
* [Issue 116](https://github.com/spyder-ide/spyder-terminal/issues/116) - Changes for compatibility with new undocking behavior of Spyder ([PR 144](https://github.com/spyder-ide/spyder-terminal/pull/144))
* [Issue 108](https://github.com/spyder-ide/spyder-terminal/issues/108) - Add terminal color schemes ([PR 160](https://github.com/spyder-ide/spyder-terminal/pull/160))

In this release 11 issues were closed.

### Pull Requests Merged

* [PR 173](https://github.com/spyder-ide/spyder-terminal/pull/173) - PR: Update to latest xterm.js version and pin dependencies
* [PR 171](https://github.com/spyder-ide/spyder-terminal/pull/171) - PR: Make some improvements to the Readme
* [PR 170](https://github.com/spyder-ide/spyder-terminal/pull/170) - PR: Fix double scroll bar appearing in Linux
* [PR 169](https://github.com/spyder-ide/spyder-terminal/pull/169) - PR: New Crowdin translations ([168](https://github.com/spyder-ide/spyder-terminal/issues/168))
* [PR 166](https://github.com/spyder-ide/spyder-terminal/pull/166) - PR: Fix styling issues for UI consistency ([161](https://github.com/spyder-ide/spyder-terminal/issues/161))
* [PR 165](https://github.com/spyder-ide/spyder-terminal/pull/165) - PR: Add scrollbar style to match Spyder dark theme
* [PR 163](https://github.com/spyder-ide/spyder-terminal/pull/163) - PR: Add shortcuts configuration
* [PR 160](https://github.com/spyder-ide/spyder-terminal/pull/160) - PR: Add themes to the terminal ([108](https://github.com/spyder-ide/spyder-terminal/issues/108))
* [PR 156](https://github.com/spyder-ide/spyder-terminal/pull/156) - PR: Add configuration entry for preferences ([159](https://github.com/spyder-ide/spyder-terminal/issues/159))
* [PR 155](https://github.com/spyder-ide/spyder-terminal/pull/155) - PR: Fix connection between Qt handler and Javascript
* [PR 154](https://github.com/spyder-ide/spyder-terminal/pull/154) - PR: Upgrade xterm to 4.2 and add search functionality
* [PR 153](https://github.com/spyder-ide/spyder-terminal/pull/153) - PR: Update xterm.js to its latest version ([138](https://github.com/spyder-ide/spyder-terminal/issues/138), [126](https://github.com/spyder-ide/spyder-terminal/issues/126))
* [PR 152](https://github.com/spyder-ide/spyder-terminal/pull/152) - PR: Update to CircleCI 2.0
* [PR 151](https://github.com/spyder-ide/spyder-terminal/pull/151) - PR: Set up CI with Azure Pipelines
* [PR 150](https://github.com/spyder-ide/spyder-terminal/pull/150) - PR: Update SpyderPluginWidget import  ([149](https://github.com/spyder-ide/spyder-terminal/issues/149))
* [PR 144](https://github.com/spyder-ide/spyder-terminal/pull/144) - PR: Add support for undocking behavior compatibility with Spyder 4 ([116](https://github.com/spyder-ide/spyder-terminal/issues/116))
* [PR 142](https://github.com/spyder-ide/spyder-terminal/pull/142) - PR: Migrate to terminado for the server ([122](https://github.com/spyder-ide/spyder-terminal/issues/122))
* [PR 141](https://github.com/spyder-ide/spyder-terminal/pull/141) - PR: Yarn migration ([137](https://github.com/spyder-ide/spyder-terminal/issues/137))

In this release 18 pull requests were closed.


## Version 0.2.4 (2018/05/31)

### Issues Closed

* [Issue 140](https://github.com/spyder-ide/spyder-terminal/issues/140) - Release 0.2.4
* [Issue 136](https://github.com/spyder-ide/spyder-terminal/issues/136) - Remove requirement on pexpect for Windows ([PR 139](https://github.com/spyder-ide/spyder-terminal/pull/139))
* [Issue 132](https://github.com/spyder-ide/spyder-terminal/issues/132) - Add import check for pywinpty ([PR 135](https://github.com/spyder-ide/spyder-terminal/pull/135))
* [Issue 131](https://github.com/spyder-ide/spyder-terminal/issues/131) - Remove compatibility check for Windows and Python 2 ([PR 133](https://github.com/spyder-ide/spyder-terminal/pull/133))
* [Issue 130](https://github.com/spyder-ide/spyder-terminal/issues/130) - Black screen in Spyder-terminal when I launch Spyer ([PR 135](https://github.com/spyder-ide/spyder-terminal/pull/135))

In this release 5 issues were closed.

### Pull Requests Merged

* [PR 139](https://github.com/spyder-ide/spyder-terminal/pull/139) - PR: Remove pexpect from windows requirements ([136](https://github.com/spyder-ide/spyder-terminal/issues/136))
* [PR 135](https://github.com/spyder-ide/spyder-terminal/pull/135) - PR: Add winpty import verification before starting plugin ([132](https://github.com/spyder-ide/spyder-terminal/issues/132), [130](https://github.com/spyder-ide/spyder-terminal/issues/130))
* [PR 134](https://github.com/spyder-ide/spyder-terminal/pull/134) - PR: Fix running tests in CI infrastructure
* [PR 133](https://github.com/spyder-ide/spyder-terminal/pull/133) - PR: Remove Windows/Py2.7 restriction ([131](https://github.com/spyder-ide/spyder-terminal/issues/131))

In this release 4 pull requests were closed.


## Version 0.2.3 (2017/10/11)

### Issues Closed

* [Issue 114](https://github.com/spyder-ide/spyder-terminal/issues/114) - AttributeError: 'QWebEngineProfile' object has no attribute 'clearHttpCache'

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 117](https://github.com/spyder-ide/spyder-terminal/pull/117) - PR: Do not clean WebEngine cache when using WebKit

In this release 1 pull request was closed.


## Version 0.2.2 (2017/08/25)


### Pull Requests Merged

* [PR 111](https://github.com/spyder-ide/spyder-terminal/pull/111) - PR: Prevent tarballs and wheels to be built without server components

In this release 1 pull request was closed.


## Version 0.2.1 (2017/08/22)

### Issues Closed

* [Issue 107](https://github.com/spyder-ide/spyder-terminal/issues/107) - Release 0.2.1
* [Issue 102](https://github.com/spyder-ide/spyder-terminal/issues/102) - Adapt close functionallity on Qt WebEngine
* [Issue 101](https://github.com/spyder-ide/spyder-terminal/issues/101) - Error on a slow start
* [Issue 99](https://github.com/spyder-ide/spyder-terminal/issues/99) - Prevent tests to get stuck on AppVeyor
* [Issue 96](https://github.com/spyder-ide/spyder-terminal/issues/96) - TypeError: 'Icon' object is not callable
* [Issue 95](https://github.com/spyder-ide/spyder-terminal/issues/95) - Close automatically a Terminal tab if it was closed from the process itself

In this release 6 issues were closed.

### Pull Requests Merged

* [PR 106](https://github.com/spyder-ide/spyder-terminal/pull/106) - PR: Replace default values for resize arguments
* [PR 103](https://github.com/spyder-ide/spyder-terminal/pull/103) - PR: QWebChannel implementation and tests
* [PR 100](https://github.com/spyder-ide/spyder-terminal/pull/100) - PR: Reduce test execution times
* [PR 98](https://github.com/spyder-ide/spyder-terminal/pull/98) - PR: Close terminal tab if process was closed

In this release 4 pull requests were closed.

## Version 0.2 (2017/07/24)

### Issues Closed

* [Issue 90](https://github.com/spyder-ide/spyder-terminal/issues/90) - Windows: Close websocket when a console is closed manually
* [Issue 85](https://github.com/spyder-ide/spyder-terminal/issues/85) - Update package dependencies on Windows
* [Issue 84](https://github.com/spyder-ide/spyder-terminal/issues/84) - Release 0.2
* [Issue 83](https://github.com/spyder-ide/spyder-terminal/issues/83) - Enable AppVeyor CI for Windows testing
* [Issue 79](https://github.com/spyder-ide/spyder-terminal/issues/79) - Bold font may not be activated on new terminals
* [Issue 77](https://github.com/spyder-ide/spyder-terminal/issues/77) - Execute initial commands only if prompt is available
* [Issue 76](https://github.com/spyder-ide/spyder-terminal/issues/76) - Copy and Paste shortcuts are disabled
* [Issue 72](https://github.com/spyder-ide/spyder-terminal/issues/72) - clear command does not work
* [Issue 71](https://github.com/spyder-ide/spyder-terminal/issues/71) - Tabify terminal next to the IPython console
* [Issue 70](https://github.com/spyder-ide/spyder-terminal/issues/70) - Use check_compatibility for PyQt4
* [Issue 69](https://github.com/spyder-ide/spyder-terminal/issues/69) - Make 0.2 to depend on Spyder 3.2
* [Issue 64](https://github.com/spyder-ide/spyder-terminal/issues/64) - Add server tests
* [Issue 22](https://github.com/spyder-ide/spyder-terminal/issues/22) - Incorporate Windows version using pywinpty

In this release 13 issues were closed.

### Pull Requests Merged

* [PR 94](https://github.com/spyder-ide/spyder-terminal/pull/94) - PR: Restore previous font rescaling behaviour
* [PR 93](https://github.com/spyder-ide/spyder-terminal/pull/93) - PR: Simplify initialization routine
* [PR 91](https://github.com/spyder-ide/spyder-terminal/pull/91) - PR: Close websocket if process was stopped on Windows
* [PR 89](https://github.com/spyder-ide/spyder-terminal/pull/89) - PR: Don't raise plugin when a new terminal is created
* [PR 88](https://github.com/spyder-ide/spyder-terminal/pull/88) - PR: Add server tests
* [PR 87](https://github.com/spyder-ide/spyder-terminal/pull/87) - PR: Simplify new terminal actions
* [PR 86](https://github.com/spyder-ide/spyder-terminal/pull/86) - PR: Several installation fixes
* [PR 82](https://github.com/spyder-ide/spyder-terminal/pull/82) - PR: Copy and Paste shortcuts update
* [PR 80](https://github.com/spyder-ide/spyder-terminal/pull/80) - PR: Bold fonts are enabled by default
* [PR 78](https://github.com/spyder-ide/spyder-terminal/pull/78) - Emit initialization commands only if prompt is ready
* [PR 75](https://github.com/spyder-ide/spyder-terminal/pull/75) - PR: Version 0.2 depends on Spyder 3.2
* [PR 74](https://github.com/spyder-ide/spyder-terminal/pull/74) - PR: Tabify terminal next to the IPython Console
* [PR 73](https://github.com/spyder-ide/spyder-terminal/pull/73) - PR: Add plugin check_compatibility
* [PR 58](https://github.com/spyder-ide/spyder-terminal/pull/58) - PR: Extend spyder-terminal to Windows

In this release 14 pull requests were closed.

## Version 0.1.2 (2017/06/27)

### Issues Closed

* [Issue 61](https://github.com/spyder-ide/spyder-terminal/issues/61) - Capture all keyboard events when a console is on focus
* [Issue 60](https://github.com/spyder-ide/spyder-terminal/issues/60) - Redirect server output and errors to a file
* [Issue 59](https://github.com/spyder-ide/spyder-terminal/issues/59) - Don't start to create consoles until the server is up and running

In this release 3 issues were closed.

### Pull Requests Merged

* [PR 66](https://github.com/spyder-ide/spyder-terminal/pull/66) - Add Release notes
* [PR 65](https://github.com/spyder-ide/spyder-terminal/pull/65) - PR: Launch first console instance only if server is up
* [PR 63](https://github.com/spyder-ide/spyder-terminal/pull/63) - PR: Make the terminal to capture all keyboard events
* [PR 62](https://github.com/spyder-ide/spyder-terminal/pull/62) - PR: Redirecting server stderr and stdout to files

In this release 4 pull requests were closed.

## Version 0.1.1 (2017/05/12)

### Issues Closed

* [Issue 48](https://github.com/spyder-ide/spyder-terminal/issues/48) - Terminal content not re-scaling to plugin size
* [Issue 47](https://github.com/spyder-ide/spyder-terminal/issues/47) - Move terminal webview to be inside a QFrame so that dock panes in Spyder are uniform
* [Issue 46](https://github.com/spyder-ide/spyder-terminal/issues/46) - Rename plugin to "Terminal"
* [Issue 45](https://github.com/spyder-ide/spyder-terminal/issues/45) - Plugin "Options menu" is empty
* [Issue 44](https://github.com/spyder-ide/spyder-terminal/issues/44) - Make mouse wheel to work
* [Issue 43](https://github.com/spyder-ide/spyder-terminal/issues/43) - Getting annoying Qt warnings

In this release 6 issues were closed.

### Pull Requests Merged

* [PR 54](https://github.com/spyder-ide/spyder-terminal/pull/54) - PR: Added more options for opening terminals at different locations
* [PR 53](https://github.com/spyder-ide/spyder-terminal/pull/53) - PR: Fixed scroller issues
* [PR 52](https://github.com/spyder-ide/spyder-terminal/pull/52) - PR: Update font size and geometry after terminal has finished loading
* [PR 51](https://github.com/spyder-ide/spyder-terminal/pull/51) - PR: Update plugin name to Terminal
* [PR 50](https://github.com/spyder-ide/spyder-terminal/pull/50) - PR: Added Content-Type header to all HTTP requests
* [PR 49](https://github.com/spyder-ide/spyder-terminal/pull/49) - PR: Removed reference to contentsChanged signal
* [PR 42](https://github.com/spyder-ide/spyder-terminal/pull/42) - PR: Use sys.executable to start the server

In this release 7 pull requests were closed.


## Version 0.1 (2017/04/11)

### Issues Closed

* [Issue 37](https://github.com/spyder-ide/spyder-terminal/issues/37) - Each terminal should be numbered sequentially
* [Issue 34](https://github.com/spyder-ide/spyder-terminal/issues/34) - Terminals should use user-defined fonts
* [Issue 32](https://github.com/spyder-ide/spyder-terminal/issues/32) - Fix text overflow when commands fill all the terminal space
* [Issue 31](https://github.com/spyder-ide/spyder-terminal/issues/31) - Prevent running this plugin if Spyder is using PyQt4
* [Issue 27](https://github.com/spyder-ide/spyder-terminal/issues/27) - Don't hard code port number
* [Issue 24](https://github.com/spyder-ide/spyder-terminal/issues/24) - Add CI Engines and Minor Tests
* [Issue 21](https://github.com/spyder-ide/spyder-terminal/issues/21) - Each terminal instance should be launched on currently opened path
* [Issue 20](https://github.com/spyder-ide/spyder-terminal/issues/20) - Create basic terminal shortcuts
* [Issue 15](https://github.com/spyder-ide/spyder-terminal/issues/15) - Server should start and end with Spyder process
* [Issue 14](https://github.com/spyder-ide/spyder-terminal/issues/14) - Extract Javascript dependencies to a bower.json file
* [Issue 12](https://github.com/spyder-ide/spyder-terminal/issues/12) - Solve security access problem
* [Issue 10](https://github.com/spyder-ide/spyder-terminal/issues/10) - Display xterm terminal inside a QWebView widget
* [Issue 6](https://github.com/spyder-ide/spyder-terminal/issues/6) - Implement basic web bash console using tornado and xterm.js
* [Issue 4](https://github.com/spyder-ide/spyder-terminal/issues/4) - Add project skeleton
* [Issue 3](https://github.com/spyder-ide/spyder-terminal/issues/3) - Write package documentation and description

In this release 15 issues were closed.

### Pull Requests Merged

* [PR 40](https://github.com/spyder-ide/spyder-terminal/pull/40) - New terminals inherit Spyder current working directory
* [PR 39](https://github.com/spyder-ide/spyder-terminal/pull/39) - Server port is now variable
* [PR 38](https://github.com/spyder-ide/spyder-terminal/pull/38) - Terminal tabs naming convention is sequential
* [PR 36](https://github.com/spyder-ide/spyder-terminal/pull/36) - Plugin import is restricted to PyQt5
* [PR 35](https://github.com/spyder-ide/spyder-terminal/pull/35) - PR: Custom font loading
* [PR 33](https://github.com/spyder-ide/spyder-terminal/pull/33) - Overflow resolution
* [PR 30](https://github.com/spyder-ide/spyder-terminal/pull/30) - PR: Fix tests
* [PR 28](https://github.com/spyder-ide/spyder-terminal/pull/28) - PR: Basic test added
* [PR 26](https://github.com/spyder-ide/spyder-terminal/pull/26) - PR: Documentation and Changelog update
* [PR 25](https://github.com/spyder-ide/spyder-terminal/pull/25) - PR: Server deploys on port 8070 by default
* [PR 23](https://github.com/spyder-ide/spyder-terminal/pull/23) - PR: Added basic shortcuts and menu entries
* [PR 19](https://github.com/spyder-ide/spyder-terminal/pull/19) - Code cleanup: Removed useless font HTML examples
* [PR 18](https://github.com/spyder-ide/spyder-terminal/pull/18) - PR: setup.py now downloads bower components before installing the plugin
* [PR 17](https://github.com/spyder-ide/spyder-terminal/pull/17) - Added README screenshot
* [PR 16](https://github.com/spyder-ide/spyder-terminal/pull/16) - Server now starts and stops with Spyder process
* [PR 13](https://github.com/spyder-ide/spyder-terminal/pull/13) - Spyder IDE integration
* [PR 11](https://github.com/spyder-ide/spyder-terminal/pull/11) - PR: Terminal is now shown inside a Qt Widget
* [PR 9](https://github.com/spyder-ide/spyder-terminal/pull/9) - PR: Modified pexpect constructor orden between OSes
* [PR 8](https://github.com/spyder-ide/spyder-terminal/pull/8) - PR: Added Py3 Compatibility
* [PR 7](https://github.com/spyder-ide/spyder-terminal/pull/7) - PR: Web terminal proof-of-concept
* [PR 5](https://github.com/spyder-ide/spyder-terminal/pull/5) - Add plugin template skeleton

In this release 21 pull requests were closed.
